==> 3050-PostSoftwareAssuranceTool-1.1.0-1.zip: KMessageBoxDlg.h <==
#if !defined(AFX_KMESSAGEBOXDLG_H__41937AA4_4B5B_4861_9CC3_215E5B208383__INCLUDED_)
#define AFX_KMESSAGEBOXDLG_H__41937AA4_4B5B_4861_9CC3_215E5B208383__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000
// KMessageBoxDlg.h : header file
//

/////////////////////////////////////////////////////////////////////////////
// KMessageBoxDlg dialog

class KMessageBoxDlg : public CDialog
{
// Construction
public:
	KMessageBoxDlg(CWnd* pParent = NULL);   // standard constructor

	void SetData( CString strMessage, CString strTitle, UINT nType );
	void DrawBackground ( CDC* pDC );
	void SetWindowPosition ( CRect rtPosition );
	void DrawText ( CDC* pDC );
	CString m_strMessage;
	CString m_strTitle;
	UINT m_nType;
	CBitmap			m_bmBackground;
	CPoint			m_ptPosition;

// Dialog Data
	//enum { IDD = IDD_KMESSAGEBOX_DIALOG 225 };
	//{{AFX_DATA(KMessageBoxDlg)
	enum { IDD = 225 };
	CEdit	m_edtMessage;
	YButton	m_btnYes;
	YButton	m_btnOk;
	YButton	m_btnNo;
	//}}AFX_DATA


// Overrides
	// ClassWizard generated virtual function overrides
	//{{AFX_VIRTUAL(KMessageBoxDlg)
	protected:
	virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support
	//}}AFX_VIRTUAL

// Implementation
protected:

	// Generated message map functions
	//{{AFX_MSG(KMessageBoxDlg)
	afx_msg void OnButtonNo();
	afx_msg void OnButtonOk();
	afx_msg void OnButtonYes();
	afx_msg void OnPaint();
	virtual BOOL OnInitDialog();
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
};

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ will insert additional declarations immediately before the previous line.

#endif // !defined(AFX_KMESSAGEBOXDLG_H__41937AA4_4B5B_4861_9CC3_215E5B208383__INCLUDED_)

==> 3050-PostSoftwareAssuranceTool-1.2.2-1.zip: KMessageBoxDlg.h <==
#if !defined(AFX_KMESSAGEBOXDLG_H__41937AA4_4B5B_4861_9CC3_215E5B208383__INCLUDED_)
#define AFX_KMESSAGEBOXDLG_H__41937AA4_4B5B_4861_9CC3_215E5B208383__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000
// KMessageBoxDlg.h : header file
//

/////////////////////////////////////////////////////////////////////////////
// KMessageBoxDlg dialog

class KMessageBoxDlg : public CDialog
{
// Construction
public:
	KMessageBoxDlg(CWnd* pParent = NULL);   // standard constructor

	void SetData( CString strMessage, CString strTitle, UINT nType );
	void DrawBackground ( CDC* pDC );
	void SetWindowPosition ( CRect rtPosition );
	CString m_strMessage;
	CString m_strTitle;
	UINT m_nType;
	CFont			m_MenuBackFont;
	CFont			m_MenuForeFont;
	CBitmap			m_bmBackground;
	CPoint			m_ptPosition;
	
// Dialog Data
	//enum { IDD = IDD_KMESSAGEBOX_DIALOG 225 };
	//{{AFX_DATA(KMessageBoxDlg)
	enum { IDD = 225 };
	CStatic	m_staticMessage;
	YButton	m_btnYes;
	YButton	m_btnOk;
	YButton	m_btnNo;
	//}}AFX_DATA


// Overrides
	// ClassWizard generated virtual function overrides
	//{{AFX_VIRTUAL(KMessageBoxDlg)
	protected:
	virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support
	//}}AFX_VIRTUALE

// Implementation
protected:

	// Generated message map functions
	//{{AFX_MSG(KMessageBoxDlg)
	afx_msg void OnButtonNo();
	afx_msg void OnButtonOk();
	afx_msg void OnButtonYes();
	afx_msg void OnPaint();
	virtual BOOL OnInitDialog();
	afx_msg HBRUSH OnCtlColor(CDC* pDC, CWnd* pWnd, UINT nCtlColor);
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
};

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ will insert additional declarations immediately before the previous line.

#endif // !defined(AFX_KMESSAGEBOXDLG_H__41937AA4_4B5B_4861_9CC3_215E5B208383__INCLUDED_)
